@@ -10,7 +10,7 @@ use vars qw{$err $errstr $drh $sqlite_version};
 use vars qw{%COLLATION};
 
 BEGIN {
-    $VERSION = '1.26_05';
+    $VERSION = '1.26_06';
     @ISA     = 'DynaLoader';
 
     # Initialize errors
@@ -114,7 +114,7 @@ sub connect {
     }
 
     # Hand off to the actual login function
-    DBD::SQLite::db::_login($dbh, $real, $user, $auth) or return undef;
+    DBD::SQLite::db::_login($dbh, $real, $user, $auth, $attr) or return undef;
 
     # Register the on-demand collation installer
     $DBI::VERSION >= 1.608 
@@ -137,20 +137,20 @@ sub connect {
 
 
 sub install_collation {
-  my ($dbh, $collation_name) = @_;
-  my $collation = $DBD::SQLite::COLLATION{$collation_name}
-    or die "can't install, unknown collation : $collation_name";
-  $DBI::VERSION >= 1.608 
-      ? $dbh->sqlite_create_collation($collation_name => $collation)
-      : $dbh->func($collation_name => $collation, "create_collation");
+    my ($dbh, $collation_name) = @_;
+    my $collation = $DBD::SQLite::COLLATION{$collation_name}
+        or die "can't install, unknown collation : $collation_name";
+    $DBI::VERSION >= 1.608 
+        ? $dbh->sqlite_create_collation($collation_name => $collation)
+        : $dbh->func($collation_name => $collation, "create_collation");
 }
 
 # default implementation for sqlite 'REGEXP' infix operator.
 # Note : args are reversed, i.e. "a REGEXP b" calls REGEXP(b, a)
 # (see http://www.sqlite.org/vtab.html#xfindfunction)
 sub regexp { 
-  use locale;
-  return scalar($_[1] =~ $_[0]);
+    use locale;
+    return scalar($_[1] =~ $_[0]);
 }
 
 
@@ -209,7 +209,7 @@ sub table_info {
     if (  defined($cat_val) && $cat_val eq '%'
        && defined($sch_val) && $sch_val eq ''
        && defined($tbl_val) && $tbl_val eq '')  { # Rule 19a
-            $sql = <<'END_SQL';
+        $sql = <<'END_SQL';
 SELECT NULL TABLE_CAT
      , NULL TABLE_SCHEM
      , NULL TABLE_NAME
@@ -220,7 +220,7 @@ END_SQL
     elsif (  defined($cat_val) && $cat_val eq ''
           && defined($sch_val) && $sch_val eq '%'
           && defined($tbl_val) && $tbl_val eq '') { # Rule 19b
-            $sql = <<'END_SQL';
+        $sql = <<'END_SQL';
 SELECT NULL      TABLE_CAT
      , t.tn      TABLE_SCHEM
      , NULL      TABLE_NAME
@@ -230,16 +230,16 @@ FROM (
      SELECT 'main' tn
      UNION SELECT 'temp' tn
 END_SQL
-            for my $db_name (_attached_database_list($dbh)) {
-                $sql .= "     UNION SELECT '$db_name' tn\n";
-            }
-            $sql .= ") t\n";
+        for my $db_name (_attached_database_list($dbh)) {
+            $sql .= "     UNION SELECT '$db_name' tn\n";
+        }
+        $sql .= ") t\n";
     }
     elsif (  defined($cat_val) && $cat_val eq ''
           && defined($sch_val) && $sch_val eq ''
           && defined($tbl_val) && $tbl_val eq ''
           && defined($typ_val) && $typ_val eq '%') { # Rule 19c
-            $sql = <<'END_SQL';
+        $sql = <<'END_SQL';
 SELECT NULL TABLE_CAT
      , NULL TABLE_SCHEM
      , NULL TABLE_NAME
@@ -254,7 +254,7 @@ ORDER BY TABLE_TYPE
 END_SQL
     }
     else {
-            $sql = <<'END_SQL';
+        $sql = <<'END_SQL';
 SELECT *
 FROM
 (
@@ -272,15 +272,15 @@ UNION ALL
     FROM sqlite_temp_master
 END_SQL
 
-            for my $db_name (_attached_database_list($dbh)) {
-                    $sql .= <<"END_SQL";
+        for my $db_name (_attached_database_list($dbh)) {
+            $sql .= <<"END_SQL";
 UNION ALL
     SELECT '$db_name' TABLE_SCHEM, tbl_name, upper(type) TABLE_TYPE, sql
     FROM "$db_name".sqlite_master
 END_SQL
-            }
+        }
 
-            $sql .= <<'END_SQL';
+        $sql .= <<'END_SQL';
 UNION ALL
     SELECT 'main' TABLE_SCHEM, 'sqlite_master'      tbl_name, 'SYSTEM TABLE' TABLE_TYPE, NULL sql
 UNION ALL
@@ -288,29 +288,29 @@ UNION ALL
 )
 )
 END_SQL
-            $attr = {} unless ref $attr eq 'HASH';
-            my $escape = defined $attr->{Escape} ? " ESCAPE '$attr->{Escape}'" : '';
-            if ( defined $sch_val ) {
-                    push @where, "TABLE_SCHEM LIKE '$sch_val'$escape";
+        $attr = {} unless ref $attr eq 'HASH';
+        my $escape = defined $attr->{Escape} ? " ESCAPE '$attr->{Escape}'" : '';
+        if ( defined $sch_val ) {
+            push @where, "TABLE_SCHEM LIKE '$sch_val'$escape";
+        }
+        if ( defined $tbl_val ) {
+            push @where, "TABLE_NAME LIKE '$tbl_val'$escape";
+        }
+        if ( defined $typ_val ) {
+            my $table_type_list;
+            $typ_val =~ s/^\s+//;
+            $typ_val =~ s/\s+$//;
+            my @ttype_list = split (/\s*,\s*/, $typ_val);
+            foreach my $table_type (@ttype_list) {
+                if ($table_type !~ /^'.*'$/) {
+                    $table_type = "'" . $table_type . "'";
+                }
             }
-            if ( defined $tbl_val ) {
-                    push @where, "TABLE_NAME LIKE '$tbl_val'$escape";
-            }
-            if ( defined $typ_val ) {
-                    my $table_type_list;
-                    $typ_val =~ s/^\s+//;
-                    $typ_val =~ s/\s+$//;
-                    my @ttype_list = split (/\s*,\s*/, $typ_val);
-                    foreach my $table_type (@ttype_list) {
-                            if ($table_type !~ /^'.*'$/) {
-                                    $table_type = "'" . $table_type . "'";
-                            }
-                    }
-                    $table_type_list = join(', ', @ttype_list);
-                    push @where, "TABLE_TYPE IN (\U$table_type_list)" if $table_type_list;
-            }
-            $sql .= ' WHERE ' . join("\n   AND ", @where ) . "\n" if @where;
-            $sql .= " ORDER BY TABLE_TYPE, TABLE_SCHEM, TABLE_NAME\n";
+            $table_type_list = join(', ', @ttype_list);
+            push @where, "TABLE_TYPE IN (\U$table_type_list)" if $table_type_list;
+        }
+        $sql .= ' WHERE ' . join("\n   AND ", @where ) . "\n" if @where;
+        $sql .= " ORDER BY TABLE_TYPE, TABLE_SCHEM, TABLE_NAME\n";
     }
     my $sth = $dbh->prepare($sql) or return undef;
     $sth->execute or return undef;
@@ -547,16 +547,16 @@ require Tie::Hash;
 our @ISA = qw(Tie::StdHash);
 
 sub TIEHASH {
-  bless {}, $_[0];
+    bless {}, $_[0];
 }
 
 sub STORE {
-  ! exists $_[0]->{$_[1]} or die "entry $_[1] already registered";
-  $_[0]->{$_[1]} = $_[2];
+    ! exists $_[0]->{$_[1]} or die "entry $_[1] already registered";
+    $_[0]->{$_[1]} = $_[2];
 }
 
 sub DELETE {
-  die "deletion of entry $_[1] is forbidden";
+    die "deletion of entry $_[1] is forbidden";
 }
 
 1;
@@ -614,17 +614,217 @@ SQL parser.
 
 There's lots more to it, so please refer to the docs on the SQLite web
 page, listed above, for SQL details. Also refer to L<DBI> for details
-on how to use DBI itself.
+on how to use DBI itself. The API works like every DBI module does.
+However, currently many statement attributes are not implemented or
+are limited by the typeless nature of the SQLite database.
 
-=head1 CONFORMANCE WITH DBI SPECIFICATION
+=head1 NOTABLE DIFFERENCES FROM OTHER DRIVERS
 
-The API works like every DBI module does. Please see L<DBI> for more
-details about core features.
+=head2 Database Name Is A File Name
 
-Currently many statement attributes are not implemented or are
-limited by the typeless nature of the SQLite database.
+SQLite creates a file per a database. You should pass the C<path> of
+the database file (with or without a parent directory) in the DBI
+connection string (as a database C<name>):
 
-=head3 B<table_info>
+  my $dbh = DBI->connect("dbi:SQLite:dbname=$dbfile","","");
+
+The file is opened in read/write mode, and will be created if
+it does not exist yet. 
+
+Although the database is stored in a single file, the directory
+containing the database file must be writable by SQLite because the
+library will create several temporary files there.
+
+If the filename C<$dbfile> is ":memory:", then a private, temporary
+in-memory database is created for the connection. This in-memory
+database will vanish when the database connection is closed.
+It is handy for your library tests.
+
+Note that future versions of SQLite might make use of additional
+special filenames that begin with the ":" character. It is recommended
+that when a database filename actually does begin with a ":" character
+you should prefix the filename with a pathname such as "./" to avoid
+ambiguity.
+
+If the filename C<$dbfile> is an empty string, then a private,
+temporary on-disk database will be created. This private database will
+be automatically deleted as soon as the database connection is closed.
+
+=head2 Accessing A Database With Other Tools
+
+To access the database from the command line, try using C<dbish>
+which comes with the L<DBI::Shell> module. Just type:
+
+  dbish dbi:SQLite:foo.db
+
+On the command line to access the file F<foo.db>.
+
+Alternatively you can install SQLite from the link above without
+conflicting with B<DBD::SQLite> and use the supplied C<sqlite3>
+command line tool.
+
+=head2 Blobs
+
+As of version 1.11, blobs should "just work" in SQLite as text columns.
+However this will cause the data to be treated as a string, so SQL
+statements such as length(x) will return the length of the column as a NUL
+terminated string, rather than the size of the blob in bytes. In order to
+store natively as a BLOB use the following code:
+
+  use DBI qw(:sql_types);
+  my $dbh = DBI->connect("dbi:SQLite:dbfile","","");
+  
+  my $blob = `cat foo.jpg`;
+  my $sth = $dbh->prepare("INSERT INTO mytable VALUES (1, ?)");
+  $sth->bind_param(1, $blob, SQL_BLOB);
+  $sth->execute();
+
+And then retrieval just works:
+
+  $sth = $dbh->prepare("SELECT * FROM mytable WHERE id = 1");
+  $sth->execute();
+  my $row = $sth->fetch;
+  my $blobo = $row->[1];
+  
+  # now $blobo == $blob
+
+=head2 Functions And Bind Parameters
+
+As of this writing, a SQL that compares a return value of a function
+with a numeric bind value like this doesn't work as you might expect.
+
+  my $sth = $dbh->prepare(q{
+    SELECT bar FROM foo GROUP BY bar HAVING count(*) > ?;
+  });
+  $sth->execute(5);
+
+This is because DBD::SQLite assumes that all the bind values are text
+(and should be quoted) by default. Thus the above statement becomes
+like this while executing:
+
+  SELECT bar FROM foo GROUP BY bar HAVING count(*) > "5";
+
+There are two workarounds for this.
+
+=over 4
+
+=item Use bind_param() explicitly
+
+As shown above in the C<BLOB> section, you can always use
+C<bind_param()> to tell the type of a bind value.
+
+  use DBI qw(:sql_types);  # Don't forget this
+  
+  my $sth = $dbh->prepare(q{
+    SELECT bar FROM foo GROUP BY bar HAVING count(*) > ?;
+  });
+  $sth->bind_param(1, 5, SQL_INTEGER);
+  $sth->execute();
+
+=item Add zero to make it a number
+
+This is somewhat weird, but works anyway.
+
+  my $sth = $dbh->prepare(q{
+    SELECT bar FROM foo GROUP BY bar HAVING count(*) > (? + 0);
+  });
+  $sth->execute(5);
+
+=back
+
+=head2 Foreign Keys
+
+Since SQLite 3.6.19 (released on Oct 14, 2009; bundled with
+DBD::SQLite 1.26_05), foreign key constraints are supported (though
+with some limitations). See L<http://www.sqlite.org/foreignkeys.html>
+for details. Though SQLite does NOT enable this feature by default yet (for backward compatibility), DBD::SQLite enables it internally. If you don't want this feature, issue a pragma to disable the feature.
+
+  $dbh->do("PRAGMA foreign_keys = OFF");
+
+=head2 Pragma
+
+SQLite has a set of "Pragma"s to modifiy its operation or to query for its internal data. These are specific to SQLite and are not likely to work with other DBD libraries, but you may find some of these are quite useful. DBD::SQLite actually sets some (like C<foreign_keys> above) for you when you connect to a database. See L<http://www.sqlite.org/pragma.html> for details.
+
+=head2 Performance
+
+SQLite is fast, very fast. Matt processed my 72MB log file with it,
+inserting the data (400,000+ rows) by using transactions and only
+committing every 1000 rows (otherwise the insertion is quite slow),
+and then performing queries on the data.
+
+Queries like count(*) and avg(bytes) took fractions of a second to
+return, but what surprised him most of all was:
+
+  SELECT url, count(*) as count
+  FROM access_log
+  GROUP BY url
+  ORDER BY count desc
+  LIMIT 20
+
+To discover the top 20 hit URLs on the site (L<http://axkit.org>),
+and it returned within 2 seconds. He was seriously considering
+switching his log analysis code to use this little speed demon!
+
+Oh yeah, and that was with no indexes on the table, on a 400MHz PIII.
+
+For best performance be sure to tune your hdparm settings if you 
+are using linux. Also you might want to set:
+
+  PRAGMA default_synchronous = OFF
+
+Which will prevent sqlite from doing fsync's when writing (which
+slows down non-transactional writes significantly) at the expense
+of some peace of mind. Also try playing with the cache_size pragma.
+
+The memory usage of SQLite can also be tuned using the cache_size
+pragma.
+
+  $dbh->do("PRAGMA cache_size = 800000");
+
+The above will allocate 800M for DB cache; the default is 2M.
+Your sweet spot probably lies somewhere in between.
+
+=head1 DRIVER PRIVATE ATTRIBUTES
+
+=head2 Database Handle Attributes
+
+=over 4
+
+=item sqlite_version
+
+Returns the version of the SQLite library which B<DBD::SQLite> is using,
+e.g., "2.8.0". Can only be read.
+
+=item sqlite_unicode
+
+If set to a true value, B<DBD::SQLite> will turn the UTF-8 flag on for all
+text strings coming out of the database (this feature is currently disabled
+for perl < 5.8.5). For more details on the UTF-8 flag see
+L<perlunicode>. The default is for the UTF-8 flag to be turned off.
+
+Also note that due to some bizarreness in SQLite's type system (see
+L<http://www.sqlite.org/datatype3.html>), if you want to retain
+blob-style behavior for B<some> columns under C<< $dbh->{sqlite_unicode} = 1
+>> (say, to store images in the database), you have to state so
+explicitly using the 3-argument form of L<DBI/bind_param> when doing
+updates:
+
+  use DBI qw(:sql_types);
+  $dbh->{sqlite_unicode} = 1;
+  my $sth = $dbh->prepare("INSERT INTO mytable (blobcolumn) VALUES (?)");
+  
+  # Binary_data will be stored as is.
+  $sth->bind_param(1, $binary_data, SQL_BLOB);
+
+Defining the column type as C<BLOB> in the DDL is B<not> sufficient.
+
+As of version 1.26_06, C<unicode> is renamed to C<sqlite_unicode> for integrity. Old C<unicode> attribute is still accessible but will be deprecated in the near future.
+
+=back
+
+=head1 METHODS
+
+=head2 table_info
 
   $sth = $dbh->table_info(undef, $schema, $table, $type, \%attr);
 
@@ -648,65 +848,6 @@ B<TABLE_NAME>: The name of the table or view.
 B<TABLE_TYPE>: The type of object returned. Will be one of 'TABLE', 'VIEW',
 'LOCAL TEMPORARY' or 'SYSTEM TABLE'.
 
-=head1 CONNECTING
-
-The name of the database file is passed in the the DBI connection 
-string :
-
-  my $dbh = DBI->connect("dbi:SQLite:dbname=$dbfile","","");
-
-The file is opened in read/write mode, and will be created if
-it does not exist yet. 
-
-If the filename C<$dbfile> is ":memory:", then a private, temporary
-in-memory database is created for the connection. This in-memory
-database will vanish when the database connection is closed. Future
-versions of SQLite might make use of additional special filenames that
-begin with the ":" character. It is recommended that when a database
-filename actually does begin with a ":" character you should prefix
-the filename with a pathname such as "./" to avoid ambiguity.
-
-If the filename C<$dbfile> is an empty string, then a private,
-temporary on-disk database will be created. This private database will
-be automatically deleted as soon as the database connection is closed.
-
-
-=head1 DRIVER PRIVATE ATTRIBUTES
-
-=head2 Database Handle Attributes
-
-=over 4
-
-=item sqlite_version
-
-Returns the version of the SQLite library which B<DBD::SQLite> is using,
-e.g., "2.8.0". Can only be read.
-
-=item unicode
-
-If set to a true value, B<DBD::SQLite> will turn the UTF-8 flag on for all
-text strings coming out of the database (this feature is currently disabled
-for perl < 5.8.5). For more details on the UTF-8 flag see
-L<perlunicode>. The default is for the UTF-8 flag to be turned off.
-
-Also note that due to some bizarreness in SQLite's type system (see
-L<http://www.sqlite.org/datatype3.html>), if you want to retain
-blob-style behavior for B<some> columns under C<< $dbh->{unicode} = 1
->> (say, to store images in the database), you have to state so
-explicitly using the 3-argument form of L<DBI/bind_param> when doing
-updates:
-
-  use DBI qw(:sql_types);
-  $dbh->{unicode} = 1;
-  my $sth = $dbh->prepare("INSERT INTO mytable (blobcolumn) VALUES (?)");
-  
-  # Binary_data will be stored as is.
-  $sth->bind_param(1, $binary_data, SQL_BLOB);
-
-Defining the column type as C<BLOB> in the DDL is B<not> sufficient.
-
-=back
-
 =head1 DRIVER PRIVATE METHODS
 
 The following methods can be called via the func() method with a little
@@ -1273,15 +1414,15 @@ The builtin C<perl> or C<perllocale> collations are predefined
 in that same hash.
 
 The COLLATION hash is a global registry within the current process;
- hence there is a risk of undesired side-effects. Therefore, to
- prevent action at distance, the hash is implemented as a "write-only"
- hash, that will happily accept new entries, but will raise an
- exception if any attempt is made to override or delete a existing
- entry (including the builtin C<perl> and C<perllocale>).  
+hence there is a risk of undesired side-effects. Therefore, to
+prevent action at distance, the hash is implemented as a "write-only"
+hash, that will happily accept new entries, but will raise an
+exception if any attempt is made to override or delete a existing
+entry (including the builtin C<perl> and C<perllocale>).  
 
 If you really, really need to change or delete an entry, you can
- always grab the tied object underneath C<%DBD::SQLite::COLLATION> ---
- but don't do that unless you really know what you are doing. Also
+always grab the tied object underneath C<%DBD::SQLite::COLLATION> ---
+but don't do that unless you really know what you are doing. Also
 observe that changes in the global hash will not modify existing
 collations in existing database handles: it will only affect new
 I<requests> for collations. In other words, if you want to change
@@ -1289,129 +1430,6 @@ the behaviour of a collation within an existing C<$dbh>, you
 need to call the L</create_collation> method directly.
 
 
-=head1 BLOBS
-
-As of version 1.11, blobs should "just work" in SQLite as text columns.
-However this will cause the data to be treated as a string, so SQL
-statements such as length(x) will return the length of the column as a NUL
-terminated string, rather than the size of the blob in bytes. In order to
-store natively as a BLOB use the following code:
-
-  use DBI qw(:sql_types);
-  my $dbh = DBI->connect("dbi:SQLite:dbfile","","");
-  
-  my $blob = `cat foo.jpg`;
-  my $sth = $dbh->prepare("INSERT INTO mytable VALUES (1, ?)");
-  $sth->bind_param(1, $blob, SQL_BLOB);
-  $sth->execute();
-
-And then retrieval just works:
-
-  $sth = $dbh->prepare("SELECT * FROM mytable WHERE id = 1");
-  $sth->execute();
-  my $row = $sth->fetch;
-  my $blobo = $row->[1];
-  
-  # now $blobo == $blob
-
-=head1 NOTES
-
-Although the database is stored in a single file, the directory containing the
-database file must be writable by SQLite because the library will create
-several temporary files there.
-
-To access the database from the command line, try using dbish which comes with
-the L<DBI::Shell> module. Just type:
-
-  dbish dbi:SQLite:foo.db
-
-On the command line to access the file F<foo.db>.
-
-Alternatively you can install SQLite from the link above without conflicting
-with B<DBD::SQLite> and use the supplied C<sqlite> command line tool.
-
-=head1 FUNCTIONS AND BIND PARAMETERS
-
-As of this writing, a SQL that compares a return value of a function with a
-numeric bind value like this doesn't work as you might expect.
-
-  my $sth = $dbh->prepare(q{
-    SELECT bar FROM foo GROUP BY bar HAVING count(*) > ?;
-  });
-  $sth->execute(5);
-
-This is because DBD::SQLite assumes that all the bind values are text (and
-should be quoted) by default. Thus the above statement becomes like this
-while executing:
-
-  SELECT bar FROM foo GROUP BY bar HAVING count(*) > "5";
-
-There are two workarounds for this.
-
-=over 4
-
-=item Use bind_param() explicitly
-
-As shown above in the C<BLOB> section, you can always use C<bind_param()> to
-tell the type of a bind value.
-
-  use DBI qw(:sql_types);  # Don't forget this
-  
-  my $sth = $dbh->prepare(q{
-    SELECT bar FROM foo GROUP BY bar HAVING count(*) > ?;
-  });
-  $sth->bind_param(1, 5, SQL_INTEGER);
-  $sth->execute();
-
-=item Add zero to make it a number
-
-This is somewhat weird, but works anyway.
-
-  my $sth = $dbh->prepare(q{
-    SELECT bar FROM foo GROUP BY bar HAVING count(*) > (? + 0);
-  });
-  $sth->execute(5);
-
-=back
-
-=head1 PERFORMANCE
-
-SQLite is fast, very fast. I recently processed my 72MB log file with it,
-inserting the data (400,000+ rows) by using transactions and only committing
-every 1000 rows (otherwise the insertion is quite slow), and then performing
-queries on the data.
-
-Queries like count(*) and avg(bytes) took fractions of a second to return,
-but what surprised me most of all was:
-
-  SELECT url, count(*) as count
-  FROM access_log
-  GROUP BY url
-  ORDER BY count desc
-  LIMIT 20
-
-To discover the top 20 hit URLs on the site (L<http://axkit.org>), and it
-returned within 2 seconds. I'm seriously considering switching my log
-analysis code to use this little speed demon!
-
-Oh yeah, and that was with no indexes on the table, on a 400MHz PIII.
-
-For best performance be sure to tune your hdparm settings if you are
-using linux. Also you might want to set:
-
-  PRAGMA default_synchronous = OFF
-
-Which will prevent sqlite from doing fsync's when writing (which
-slows down non-transactional writes significantly) at the expense of some
-peace of mind. Also try playing with the cache_size pragma.
-
-The memory usage of SQLite can also be tuned using the cache_size pragma.
-
-  $dbh->do("PRAGMA cache_size = 800000");
-
-The above will allocate 800M for DB cache; the default is 2M. Your sweet spot
-probably lies somewhere in between.
-
 =head1 TO DO
 
 The following items remain to be done.
@@ -1446,7 +1464,7 @@ L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=DBD-SQLite>
 
 Note that bugs of bundled sqlite library (i.e. bugs in C<sqlite3.[ch]>) should be reported to the sqlite developers at sqlite.org via their bug tracker or via their mailing list.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
 Matt Sergeant E<lt>matt@sergeant.orgE<gt>
 
@@ -1460,6 +1478,8 @@ Max Maischein E<lt>corion@cpan.orgE<gt>
 
 Laurent Dami E<lt>dami@cpan.orgE<gt>
 
+Kenichi Ishigaki E<lt>ishigaki@cpan.orgE<gt>
+
 =head1 COPYRIGHT
 
 The bundled SQLite code in this distribution is Public Domain.
